Package 'rk.doe'

Title: An RKWard plugin for generating Full Factorial, Fractional Factorial, and Response Surface designs using 'DoE.base, FrF2.'. Design Generation: Create Full Factorial, Fractional Factorial, and Response Surface designs and specialized ANOVA and interaction plots for experimental designs.
Description: An RKWard plugin for generating Full Factorial, Fractional Factorial, and Response Surface designs using 'DoE.base, FrF2.'. Design Generation: Create Full Factorial, Fractional Factorial, and Response Surface designs and specialized ANOVA and interaction plots for experimental designs.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.0.1
Built: 2026-06-04 10:03:38 UTC
Source: https://github.com/AlfCano/rk.doe

Help Index